//---------------------------------------------------------------------------
// ClimateChange
//---------------------------------------------------------------------------
#if !defined(ClimateChange_H)
  #define ClimateChange_H

#include "BehaviorBase.h"

class clGridBase;
class clSimManager;

/**
* Climate Change - version 1.0
*
* This changes plot temperature or precipitation over time. There can be two
* versions of this behavior, one doing temperature and one doing precipitation,
* in the same run.
*
* Temperature or precipitation at time t is:
* P = P1 + b * t^c
* where P1 is the starting value, c and b are parameters, and t is time elapsed,
* in years, since the beginning of the run.
*
* The user can set upper and lower bounds on the climate variable.
*
* This class's namestring is "climate change". The parameter file call string
* for the temperature version is "Temperature climate change". For
* precipitation, it's "Precipitation climate change".
*
* Copyright 2010 Charles D. Canham.
* @author Lora E. Murphy
*
  <br>Edit history:
  <br>-----------------
  <br>December 1, 2010 - Created (LEM)
*/
class clClimateChange : virtual public clBehaviorBase {
//note: need the virtual keyword to avoid base class ambiguity.

 public:

 /**
  * Constructor.
  * @param p_oSimManager Sim Manager object.
  */
 clClimateChange(clSimManager *p_oSimManager);

 /**
  * Destructor - not needed
  */
 //~clClimateChange();

 /**
  * Reads in values from the parameter file.
  * @param p_oDoc DOM tree of parsed input file.
  */
 void GetData(xercesc::DOMDocument *p_oDoc);

 /**
  * Updates the plot temperature or precipitation according to the function
  * above.
  */
 void Action();

 /**
  * Captures the namestring passed to this behavior.  This is overridden from
  * clBehaviorBase so we can capture the namestring passed.  Since this class
  * can create multiple kinds of behaviors that function differently, this will
  * capture what kind of behavior this is supposed to be.
  *
  * @param cNameString Behavior's namestring.
  */
  void SetNameData(char *cNameString);

 protected:

  /** Time, in years, elapsed since the beginning of the run.*/
  float m_fTimeElapsed;

  /** Length of timestep, in years.*/
  float m_fTimestepLength;

  /** B parameter.*/
  float m_fB;

  /** C parameter.*/
  float m_fC;

  /** Starting value, either temperature or precipitation.*/
  float m_fStartingValue;

  /** Lower bound.*/
  float m_fMin;

  /** Upper bound.*/
  float m_fMax;

  /** Whether this is for temperature (True) or precipitation (False).*/
  bool m_bIsTemp;

};
//---------------------------------------------------------------------------
#endif // ClimateChange_H

